/*
 * Copyright 2012 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.backend.system;

import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.util.Collections;
import java.util.Enumeration;
import java.util.logging.Level;
import java.util.logging.Logger;

import com.redhat.thermostat.common.NetworkInfo;
import com.redhat.thermostat.common.NetworkInterfaceInfo;
import com.redhat.thermostat.common.utils.LoggingUtils;

public class NetworkInfoBuilder {

    private static final Logger logger = LoggingUtils.getLogger(NetworkInfoBuilder.class);

    public static NetworkInfo build() {
        NetworkInfo info = new NetworkInfo();
        try {
            Enumeration<NetworkInterface> ifaces = NetworkInterface.getNetworkInterfaces();
            for (NetworkInterface iface : Collections.list(ifaces)) {
                NetworkInterfaceInfo iInfo = new NetworkInterfaceInfo(iface.getName());
                for (InetAddress addr : Collections.list(iface.getInetAddresses())) {
                    if (addr instanceof Inet4Address) {
                        iInfo.setIp4Addr(fixAddr(addr.toString()));
                    } else if (addr instanceof Inet6Address) {
                        iInfo.setIp6Addr(fixAddr(addr.toString()));
                    }
                }
                info.addNetworkInterfaceInfo(iInfo);
            }
        } catch (SocketException e) {
            logger.log(Level.WARNING, "error enumerating network interfaces");
        }
        return info;
    }

    /**
     * Removes the "hostname/" and the "%scope_id" parts from the
     * {@link InetAddress#toString()} output.
     */
    private static String fixAddr(String addr) {
        int slashPos = addr.indexOf("/");
        if (slashPos == -1) {
            return addr;
        }
        String fixed = addr.substring(slashPos + 1);
        int percentPos = fixed.indexOf("%");
        if (percentPos == -1) {
            return fixed;
        }
        fixed = fixed.substring(0, percentPos);
        return fixed;
    }
}
